# Copyright 2023 Takin Profit. All rights reserved.
# Use of this source code is governed by a BSD-style
# license that can be found in the LICENSE file.

from typing import Literal, Union

from typedhtml.tags import h1, h2, h3, h4, h5, h6

Inverse = Literal["uk-light", "uk-dark"]

Padding = Literal[
    "uk-padding",
    "uk-padding-small",
    "uk-padding-large",
    "uk-padding-remove",
    "uk-padding-remove-top",
    "uk-padding-remove-bottom",
    "uk-padding-remove-left",
    "uk-padding-remove-right",
    "uk-padding-remove-vertical",
    "uk-padding-remove-horizontal",
]

Width = Literal[
    "uk-width-auto",
    "uk-width-expand",
    "uk-width-1-1",
    "uk-width-1-2",
    "uk-width-1-3",
    "uk-width-2-3",
    "uk-width-1-4",
    "uk-width-3-4",
    "uk-width-1-5",
    "uk-width-2-5",
    "uk-width-3-5",
    "uk-width-4-5",
    "uk-width-1-6",
    "uk-width-5-6",
    "uk-child-width-1-2",
    "uk-child-width-1-3",
    "uk-child-width-1-4",
    "uk-child-width-1-5",
    "uk-child-width-1-6",
    "uk-child-width-auto",
    "uk-child-width-expand",
    "uk-width-small",
    "uk-width-medium",
    "uk-width-large",
    "uk-width-xlarge",
    "uk-width-2xlarge",
    "uk-width-1-1@m",
    "uk-width-1-2@m",
    "uk-width-1-3@m",
    "uk-width-2-3@m",
    "uk-width-1-4@m",
    "uk-width-3-4@m",
    "uk-width-1-5@m",
    "uk-width-2-5@m",
    "uk-width-3-5@m",
    "uk-width-4-5@m",
    "uk-width-1-6@m",
    "uk-width-5-6@m",
    "uk-width-auto@m",
    "uk-width-expand@m",
    "uk-width-1-1@s",
    "uk-width-1-2@s",
    "uk-width-1-3@s",
    "uk-width-2-3@s",
    "uk-width-1-4@s",
    "uk-width-3-4@s",
    "uk-width-1-5@s",
    "uk-width-2-5@s",
    "uk-width-3-5@s",
    "uk-width-4-5@s",
    "uk-width-1-6@s",
    "uk-width-5-6@s",
    "uk-width-auto@s",
    "uk-width-expand@s",
    "uk-width-1-1@l",
    "uk-width-1-2@l",
    "uk-width-1-3@l",
    "uk-width-2-3@l",
    "uk-width-1-4@l",
    "uk-width-3-4@l",
    "uk-width-1-5@l",
    "uk-width-2-5@l",
    "uk-width-3-5@l",
    "uk-width-4-5@l",
    "uk-width-1-6@l",
    "uk-width-5-6@l",
    "uk-width-auto@l",
    "uk-width-expand@l",
    "uk-width-1-1@xl",
    "uk-width-1-2@xl",
    "uk-width-1-3@xl",
    "uk-width-2-3@xl",
    "uk-width-1-4@xl",
    "uk-width-3-4@xl",
    "uk-width-1-5@xl",
    "uk-width-2-5@xl",
    "uk-width-3-5@xl",
    "uk-width-4-5@xl",
    "uk-width-1-6@xl",
    "uk-width-5-6@xl",
    "uk-width-auto@xl",
    "uk-width-expand@xl",
]

Utility = Literal[
    "uk-float-left",
    "uk-float-right",
    "uk-clearfix",
    "uk-overflow-hidden",
    "uk-overflow-auto",
    "uk-resize",
    "uk-resize-vertical",
    "uk-display-block",
    "uk-display-inline",
    "uk-display-inline-block",
    "uk-inline",
    "uk-inline-clip",
    "uk-responsive-width",
    "uk-responsive-height",
    "uk-preserve-width",
    "uk-object-cover",
    "uk-object-contain",
    "uk-object-fill",
    "uk-object-none",
    "uk-object-scale-down",
    "uk-object-position-top-left",
    "uk-object-position-top-center",
    "uk-object-position-top-right",
    "uk-object-position-center-left",
    "uk-object-position-center-center",
    "uk-object-position-center-right",
    "uk-object-position-bottom-left",
    "uk-object-position-bottom-center",
    "uk-object-position-bottom-right",
    "uk-border-rounded",
    "uk-border-circle",
    "uk-border-pill",
    "uk-box-shadow-small",
    "uk-box-shadow-medium",
    "uk-box-shadow-large",
    "uk-box-shadow-xlarge",
    "uk-box-shadow-hover-small",
    "uk-box-shadow-hover-medium",
    "uk-box-shadow-hover-large",
    "uk-box-shadow-hover-xlarge",
    "uk-dropcap",
    "uk-logo",
    "uk-blend-multiply",
    "uk-blend-screen",
    "uk-blend-overlay",
    "uk-blend-darken",
    "uk-blend-lighten",
    "uk-blend-color-dodge",
    "uk-blend-color-burn",
    "uk-blend-hard-light",
    "uk-blend-soft-light",
    "uk-blend-difference",
    "uk-blend-exclusion",
    "uk-blend-hue",
    "uk-blend-saturation",
    "uk-blend-color",
    "uk-blend-luminosity",
    "uk-transform-center",
    "uk-disabled",
    "uk-drag",
    "uk-transform-origin-top-left",
    "uk-transform-origin-top-center",
    "uk-transform-origin-top-right",
    "uk-transform-origin-center-left",
    "uk-transform-origin-center-right",
    "uk-transform-origin-bottom-left",
    "uk-transform-origin-bottom-center",
    "uk-transform-origin-bottom-right",
]
Animation = Literal[
    "uk-animation-fade",
    "uk-animation-scale-up",
    "uk-animation-scale-down",
    "uk-animation-slide-top",
    "uk-animation-slide-bottom",
    "uk-animation-slide-left",
    "uk-animation-slide-right",
    "uk-animation-slide-top-small",
    "uk-animation-slide-bottom-small",
    "uk-animation-slide-left-small",
    "uk-animation-slide-right-small",
    "uk-animation-slide-top-medium",
    "uk-animation-slide-bottom-medium",
    "uk-animation-slide-left-medium",
    "uk-animation-slide-right-medium",
    "uk-animation-kenburns",
    "uk-animation-shake",
    "uk-animation-stroke",
    "uk-animation-reverse",
    "uk-animation-fast",
]

LinkMods = Literal[
    "uk-link-toggle",
    "uk-link-reset",
    "uk-link-heading",
    "uk-link-muted",
    "uk-link-text",
]


Container = Literal[
    "uk-container-small",
    "uk-container-xsmall",
    "uk-container-large",
    "uk-container-xlarge",
    "uk-container-expand",
]

Position = Literal[
    "uk-position-top",
    "uk-position-bottom",
    "uk-position-left ",
    "uk-position-right",
    "uk-position-top-left",
    "uk-position-top-center",
    "uk-position-top-right",
    "uk-position-center",
    "uk-position-center-left",
    "uk-position-center-right",
    "uk-position-bottom-left",
    "uk-position-bottom-center",
    "uk-position-bottom-right",
    "uk-position-cover",
    "uk-position-center-left-out",
    "uk-position-center-right-out",
    "uk-position-relative",
    "uk-position-absolute",
    "uk-position-fixed",
    "uk-position-z-index",
]

HeadingType = Union[h1, h2, h3, h4, h5, h6]
Heading = Literal["h1", "h2", "h3", "h4", "h5", "h6"]
Transition = Literal["ease", "ease-in", "ease-out", "ease-in-out"]

Style = Literal["primary", "success", "warning", "danger"]

FlexClass = Literal[
    "uk-flex",
    "uk-flex-inline",
    "uk-flex-left",
    "uk-flex-center",
    "uk-flex-right",
    "uk-flex-between",
    "uk-flex-around",
    "uk-flex-left@s",
    "uk-flex-center@s",
    "uk-flex-right@s",
    "uk-flex-between@s",
    "uk-flex-around@s",
    "uk-flex-left@m",
    "uk-flex-center@m",
    "uk-flex-right@m",
    "uk-flex-between@m",
    "uk-flex-around@m",
    "uk-flex-left@l",
    "uk-flex-center@l",
    "uk-flex-right@l",
    "uk-flex-between@l",
    "uk-flex-around@l",
    "uk-flex-left@xl",
    "uk-flex-center@xl",
    "uk-flex-right@xl",
    "uk-flex-between@xl",
    "uk-flex-around@xl",
    "uk-flex-stretch",
    "uk-flex-top",
    "uk-flex-middle",
    "uk-flex-bottom",
    "uk-flex-row",
    "uk-flex-row-reverse",
    "uk-flex-column",
    "uk-flex-column-reverse",
    "uk-flex-wrap",
    "uk-flex-wrap-reverse",
    "uk-flex-nowrap",
    "uk-flex-wrap-stretch",
    "uk-flex-wrap-between",
    "uk-flex-wrap-around",
    "uk-flex-wrap-top",
    "uk-flex-wrap-middle",
    "uk-flex-wrap-bottom",
    "uk-flex-first",
    "uk-flex-last",
    "uk-flex-first@s",
    "uk-flex-last@s",
    "uk-flex-first@m",
    "uk-flex-last@m",
    "uk-flex-first@l",
    "uk-flex-last@l",
    "uk-flex-first@xl",
    "uk-flex-last@xl",
    "uk-flex-none",
    "uk-flex-auto",
    "uk-flex-1",
]


FormState = Literal["uk-form-danger", "uk-form-success"]

GridGap = Literal[
    "uk-grid-small",
    "uk-grid-medium",
    "uk-grid-large",
    "uk-grid-collapse",
    "grid_column_small",
    "grid_row_small",
    "grid_column_medium",
    "grid_row_medium",
    "grid_column_large",
    "grid_row_large",
    "grid_column_collapse",
    "grid_row_collapse",
]
